@@ -6,11 +6,11 @@ Interchange6 - Open Source Shop Machine
 
 =head1 VERSION
 
-0.101
+0.102
 
 =cut
 
-our $VERSION = '0.101';
+our $VERSION = '0.102';
 
 =head1 DESCRIPTION
 
@@ -32,7 +32,7 @@ L<Interchange6::Cart::Product>
 
 =item Cart Costs
 
-L<Interchangr6::Cart::Cost>
+L<Interchange6::Cart::Cost>
 
 Cart costs can be applied to both Carts and Cart Products and are integrated
 into each via the role L<Interchange6::Role::Costs>.
